@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com> 
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-# code imported from couchapp waiting refactor branch go to master
+# -*- coding: utf-8 -
 #
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
 
 """
 Macros used by loaders. compatible with couchapp. It allow you to include code,
@@ -95,7 +82,7 @@ def run_code_macros(f_string, app_dir, verbose=False):
     """ apply code macros"""
     def rreq(mo):
         # just read the file and return it
-        path = os.path.join(app_dir, mo.group(2).strip(' '))
+        path = os.path.join(app_dir, mo.group(2).strip())
         library = ''
         filenum = 0
         for filename in glob.iglob(path):            
@@ -125,7 +112,7 @@ def run_json_macros(doc, f_string, app_dir, verbose=False):
     def rjson(mo):
         if mo.group(2).startswith('_attachments'): 
             # someone  want to include from attachments
-           path = os.path.join(app_dir, mo.group(2).strip(' '))
+           path = os.path.join(app_dir, mo.group(2).strip())
            filenum = 0
            for filename in glob.iglob(path):
                library = ''
